@@ -319,8 +319,6 @@ class ClientUser(BaseUser):
     email: Optional[:class:`str`]
         The email the user used when registering.
 
-        .. deprecated:: 1.7
-
     locale: Optional[:class:`str`]
         The IETF language tag used to identify the language the user is using.
     mfa_enabled: :class:`bool`
@@ -358,16 +356,9 @@ class ClientUser(BaseUser):
         self.premium = data.get('premium', False)
         self.premium_type = try_enum(PremiumType, data.get('premium_type', None))
 
-    @deprecated()
     def get_relationship(self, user_id):
         """Retrieves the :class:`Relationship` if applicable.
 
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-
         Parameters
         -----------
         user_id: :class:`int`
@@ -382,38 +373,17 @@ class ClientUser(BaseUser):
 
     @property
     def relationships(self):
-        """List[:class:`User`]: Returns all the relationships that the user has.
-
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-        """
+        """List[:class:`User`]: Returns all the relationships that the user has."""
         return list(self._relationships.values())
 
     @property
     def friends(self):
-        r"""List[:class:`User`]: Returns all the users that the user is friends with.
-
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-        """
+        r"""List[:class:`User`]: Returns all the users that the user is friends with."""
         return [r.user for r in self._relationships.values() if r.type is RelationshipType.friend]
 
     @property
     def blocked(self):
-        r"""List[:class:`User`]: Returns all the users that the user has blocked.
-
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-        """
+        r"""List[:class:`User`]: Returns all the users that the user has blocked."""
         return [r.user for r in self._relationships.values() if r.type is RelationshipType.blocked]
 
     async def edit(self, **fields):
@@ -421,13 +391,6 @@ class ClientUser(BaseUser):
 
         Edits the current profile of the client.
 
-        If a bot account is used then a password field is optional,
-        otherwise it is required.
-
-        .. warning::
-
-            The user account-only fields are deprecated.
-
         .. note::
 
             To upload an avatar, a :term:`py:bytes-like object` must be passed in that
@@ -465,7 +428,7 @@ class ClientUser(BaseUser):
         InvalidArgument
             Wrong image format passed for ``avatar``.
         ClientException
-            Password is required for non-bot accounts.
+            Password was not passed.
             House field was not a HypeSquadHouse.
         """
 
@@ -482,7 +445,7 @@ class ClientUser(BaseUser):
         not_bot_account = not self.bot
         password = fields.get('password')
         if not_bot_account and password is None:
-            raise ClientException('Password is required for non-bot accounts.')
+            raise ClientException('Password is required')
 
         args = {
             'password': password,
@@ -519,7 +482,6 @@ class ClientUser(BaseUser):
 
         self._update(data)
 
-    @deprecated()
     async def create_group(self, *recipients):
         r"""|coro|
 
@@ -527,12 +489,6 @@ class ClientUser(BaseUser):
         provided. These recipients must be have a relationship
         of type :attr:`RelationshipType.friend`.
 
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-
         Parameters
         -----------
         \*recipients: :class:`User`
@@ -562,18 +518,11 @@ class ClientUser(BaseUser):
         data = await self._state.http.start_group(self.id, users)
         return GroupChannel(me=self, data=data, state=self._state)
 
-    @deprecated()
     async def edit_settings(self, **kwargs):
         """|coro|
 
         Edits the client user's settings.
 
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-
         Parameters
         -------
         afk_timeout: :class:`int`
@@ -766,28 +715,14 @@ class User(BaseUser, discord.abc.Messageable):
 
     @property
     def relationship(self):
-        """Optional[:class:`Relationship`]: Returns the :class:`Relationship` with this user if applicable, ``None`` otherwise.
-
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-        """
+        """Optional[:class:`Relationship`]: Returns the :class:`Relationship` with this user if applicable, ``None`` otherwise."""
         return self._state.user.get_relationship(self.id)
 
-    @deprecated()
     async def mutual_friends(self):
         """|coro|
 
         Gets all mutual friends of this user.
 
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-
         Raises
         -------
         Forbidden
@@ -804,48 +739,25 @@ class User(BaseUser, discord.abc.Messageable):
         mutuals = await state.http.get_mutual_friends(self.id)
         return [User(state=state, data=friend) for friend in mutuals]
 
-    @deprecated()
     def is_friend(self):
-        """:class:`bool`: Checks if the user is your friend.
-
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-        """
+        """:class:`bool`: Checks if the user is your friend."""
         r = self.relationship
         if r is None:
             return False
         return r.type is RelationshipType.friend
 
-    @deprecated()
     def is_blocked(self):
-        """:class:`bool`: Checks if the user is blocked.
-
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-        """
+        """:class:`bool`: Checks if the user is blocked."""
         r = self.relationship
         if r is None:
             return False
         return r.type is RelationshipType.blocked
 
-    @deprecated()
     async def block(self):
         """|coro|
 
         Blocks the user.
 
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-
         Raises
         -------
         Forbidden
@@ -856,18 +768,11 @@ class User(BaseUser, discord.abc.Messageable):
 
         await self._state.http.add_relationship(self.id, type=RelationshipType.blocked.value)
 
-    @deprecated()
     async def unblock(self):
         """|coro|
 
         Unblocks the user.
 
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-
         Raises
         -------
         Forbidden
@@ -877,18 +782,11 @@ class User(BaseUser, discord.abc.Messageable):
         """
         await self._state.http.remove_relationship(self.id)
 
-    @deprecated()
     async def remove_friend(self):
         """|coro|
 
         Removes the user as a friend.
 
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-
         Raises
         -------
         Forbidden
@@ -898,18 +796,11 @@ class User(BaseUser, discord.abc.Messageable):
         """
         await self._state.http.remove_relationship(self.id)
 
-    @deprecated()
     async def send_friend_request(self):
         """|coro|
 
         Sends the user a friend request.
 
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-
         Raises
         -------
         Forbidden
@@ -919,18 +810,11 @@ class User(BaseUser, discord.abc.Messageable):
         """
         await self._state.http.send_friend_request(username=self.name, discriminator=self.discriminator)
 
-    @deprecated()
     async def profile(self):
         """|coro|
 
         Gets the user's profile.
 
-        .. deprecated:: 1.7
-
-        .. note::
-
-            This can only be used by non-bot accounts.
-
         Raises
         -------
         Forbidden
